# ifndef yyCheckHome
# define yyCheckHome

# if defined __STDC__ | defined __cplusplus
# define ARGS(parameters)	parameters
# else
# define ARGS(parameters)	()
# endif

# ifndef rbool
# define rbool char
# endif

# include "Tree.h"
# include "Definitions.h"

/* line 25 "CheckHome.puma" */


#include "VarDescriptor.h"



extern void (* CheckHome_Exit) ARGS ((void));

extern void CheckHome ARGS ((tTree t));

extern void BeginCheckHome ARGS ((void));
extern void CloseCheckHome ARGS ((void));

# endif
